==> R14.1.1-core.tar: tdevelop-trinity-14.1.1/kdevdesigner/designer/timestamp.cpp <==
 /**********************************************************************
** Copyright (C) 2000 Trolltech AS.  All rights reserved.
**
** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include "timestamp.h"
#include <tqfile.h>
#include <tqfileinfo.h>

class TQTimer;

TimeStamp::TimeStamp( TQObject *parent, const TQString &f )
    : TQObject( parent ), filename( f ), autoCheck( FALSE )
{
    timer = new TQTimer( this );
    connect( timer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( autoCheckTimeStamp() ) );
    update();
}

void TimeStamp::setFileName( const TQString &f )
{
    filename = f;
    update();
}

TQString TimeStamp::fileName() const
{
    return filename;
}

void TimeStamp::setAutoCheckEnabled( bool a )
{
    autoCheck = a;
    if ( autoCheck )
	timer->start( 5000 );
    else
	timer->stop();
}

void TimeStamp::update()
{
    TQFile f( filename );
    if ( !f.exists() )
	return;
    lastTimeStamp = TQFileInfo( f ).lastModified();
}

bool TimeStamp::isUpToDate() const
{
    TQFile f( filename );
    if ( !f.exists() )
	return TRUE;
    return lastTimeStamp == TQFileInfo( f ).lastModified();
}

bool TimeStamp::isAutoCheckEnabled() const
{
    return autoCheck;
}

void TimeStamp::autoCheckTimeStamp()
{
    if ( !isUpToDate() )
	emit timeStampChanged();
}

==> R14.1.2-core.tar: tdevelop-trinity-14.1.2/kdevdesigner/designer/timestamp.cpp <==
 /**********************************************************************
** Copyright (C) 2000 Trolltech AS.  All rights reserved.
**
** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
**********************************************************************/

#include "timestamp.h"
#include <tqfile.h>
#include <tqfileinfo.h>

class TQTimer;

TimeStamp::TimeStamp( TQObject *parent, const TQString &f )
    : TQObject( parent ), filename( f ), autoCheck( FALSE )
{
    timer = new TQTimer( this );
    connect( timer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( autoCheckTimeStamp() ) );
    update();
}

void TimeStamp::setFileName( const TQString &f )
{
    filename = f;
    update();
}

TQString TimeStamp::fileName() const
{
    return filename;
}

void TimeStamp::setAutoCheckEnabled( bool a )
{
    autoCheck = a;
    if ( autoCheck )
	timer->start( 5000 );
    else
	timer->stop();
}

void TimeStamp::update()
{
    TQFile f( filename );
    if ( !f.exists() )
	return;
    lastTimeStamp = TQFileInfo( f ).lastModified();
}

bool TimeStamp::isUpToDate() const
{
    TQFile f( filename );
    if ( !f.exists() )
	return TRUE;
    return lastTimeStamp == TQFileInfo( f ).lastModified();
}

bool TimeStamp::isAutoCheckEnabled() const
{
    return autoCheck;
}

void TimeStamp::autoCheckTimeStamp()
{
    if ( !isUpToDate() )
	emit timeStampChanged();
}
